package com.njcn.mysql.service;

public interface OracleToMysqlService {

    /**
     * r_stat_data_harmrate_v_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertDayHarmRateV(String startTime, String endTime);

    /**
     * r_stat_integrity_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertPqsIntegrity(String startTime, String endTime);

    /**
     * r_stat_data_v_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertDayV(String startTime, String endTime);

    /**
     * r_stat_limit_rate_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertLimitRate(String startTime, String endTime);

    /**
     * r_stat_limit_target_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertLimitTarget(String startTime, String endTime);

    /**
     * r_stat_comasses_data数据插入
     * @param startTime
     * @param endTime
     */
    void insertComAsses(String startTime, String endTime);
    /**
     * r_stat_asses_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertAsses(String startTime, String endTime);

    /**
     * r_stat_data_i_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertDataI(String startTime, String endTime);

    /**
     * r_stat_data_plt_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertPlt(String startTime, String endTime);

    /**
     * r_stat_data_flicker_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertFlicker(String startTime, String endTime);

    /**
     * r_stat_data_inharm_v_d数据插入
     * @param startTime
     * @param endTime
     */
    void insertInHarmV(String startTime, String endTime);

    /**
     * @Description: 监测团运行状态同步
     * @param
     * @Author: wr
     */
    void LineRunFlag();

    /**
     * @Description: 监测点电网变电站同步
     */
    void lineSubstation();
}
